package io.zipcoder;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;

public class ItemParser {


    public ArrayList<String> parseRawDataIntoStringArray(String rawData){
        String stringPattern = "##";
        ArrayList<String> response = splitStringWithRegexPattern(stringPattern , rawData);
        return response;
    }

    public Item parseStringIntoItem(HashMap<String, String> itemMap) throws ItemParseException {

        String name = null;
        Double price = null;
        String type = null;
        String expiration = null;

        if(checkForEmptyValues(itemMap)) {
            throw new ItemParseException("Missing Values");
        } else {
            for (String key : itemMap.keySet()) {
                if (key.matches("(?i:.*NAME.*)")) {
                    if (!itemMap.get(key).equals(""))
                        name = identifyName(itemMap.get(key));
                }
                if (key.matches("(?i:.*PRICE.*)")) {
                    if (!itemMap.get(key).equals(""))
                        price = Double.parseDouble(itemMap.get(key));
                }
                if (key.matches("(?i:.*TYPE.*)")) {
                    if (!itemMap.get(key).equals(""))
                        type = itemMap.get(key);
                }
                if (key.matches("(?i:.*EXPIRATION.*)")) {
                    if (!itemMap.get(key).equals(""))
                        expiration = itemMap.get(key);
                }
            }
        }

        return new Item(name, price, type, expiration);
    }

    public ArrayList<String> findKeyValuePairsInRawItemData(String rawItem){
        String stringPattern = "[:!;^%*@!]";
        ArrayList<String> response = splitStringWithRegexPattern(stringPattern , rawItem);
        return response;
    }

    private ArrayList<String> splitStringWithRegexPattern(String stringPattern, String inputString){
        return new ArrayList<String>(Arrays.asList(inputString.split(stringPattern)));
    }

    public HashMap<String, String> mapKeysAndValuesOfItem(String rawItem) {
        ArrayList<String> item = findKeyValuePairsInRawItemData(rawItem);
        HashMap<String, String> itemMap = new HashMap<String, String>();
        for (int i = 0; i < item.size(); i+=2) {
            itemMap.put(item.get(i), item.get(i+1));
        }
        return itemMap;
    }

    public boolean checkForEmptyValues(HashMap<String, String> itemMap) {
        for(String s: itemMap.keySet()) {
        if(itemMap.get(s).equals("")) {
            return true;
            }
        }
        return false;
    }


    public String identifyName(String input) {
        if(input.matches("(?i:.*bread.*)"))
            return "bread";
        if(input.matches("(?i:.*milk.*)"))
            return "milk";
        if(input.matches("(?i:.*apples.*)"))
            return "apples";
        if(input.matches("[Cc][Oo0]{2}(?i:.*kies.*)"))
            return "cookies";

        return null;
    }

}
