package io.zipcoder;

import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import java.util.ArrayList;

import static org.junit.Assert.*;

public class ItemParserTest {

    private String rawSingleItem =    "naMe:Milk;price:3.23;type:Food;expiration:1/25/2016##";

    private String rawSingleItemIrregularSeperatorSample = "naMe:MiLK;price:3.23;type:Food^expiration:1/11/2016##";

    private String rawBrokenSingleItem =    "naMe:;price:3.23;type:Food;expiration:1/25/2016##";

    private String rawMultipleItems = "naMe:Milk;price:3.23;type:Food;expiration:1/25/2016##"
                                      +"naME:BreaD;price:1.23;type:Food;expiration:1/02/2016##"
                                      +"NAMe:BrEAD;price:1.23;type:Food;expiration:2/25/2016##";
    private ItemParser itemParser;

    @Before
    public void setUp(){
        itemParser = new ItemParser();
    }

    @Test
    public void parseRawDataIntoStringArrayTest(){
        Integer expectedArraySize = 3;
        ArrayList<String> items = itemParser.parseRawDataIntoStringArray(rawMultipleItems);
        Integer actualArraySize = items.size();
        assertEquals(expectedArraySize, actualArraySize);
    }

    @Test
    public void parseStringIntoItemTest() throws ItemParseException{
        Item expected = new Item("milk", 3.23, "food","1/25/2016");
        ArrayList<String> itemArray = itemParser.parseRawDataIntoStringArray(rawSingleItem);
        Item actual = itemParser.parseStringIntoItem(itemParser.mapKeysAndValuesOfItem(itemArray.get(0)));
        assertEquals(expected, actual);
    }

    @Test(expected = ItemParseException.class)
    public void parseBrokenStringIntoItemTest() throws ItemParseException{
        ArrayList<String> itemArray = itemParser.parseRawDataIntoStringArray(rawBrokenSingleItem);
        Item actual = itemParser.parseStringIntoItem(itemParser.mapKeysAndValuesOfItem(itemArray.get(0)));    }

    @Test
    public void findKeyValuePairsInRawItemDataTest(){
        Integer expected = 8;
        ArrayList<String> itemArray = itemParser.parseRawDataIntoStringArray(rawBrokenSingleItem);
        Integer actual = itemParser.findKeyValuePairsInRawItemData(itemArray.get(0)).size();
        assertEquals(expected, actual);
    }

    @Test
    public void findKeyValuePairsInRawItemDataTestIrregular(){
        Integer expected = 8;
        ArrayList<String> itemArray = itemParser.parseRawDataIntoStringArray(rawSingleItemIrregularSeperatorSample);
        Integer actual = itemParser.findKeyValuePairsInRawItemData(itemArray.get(0)).size();
        assertEquals(expected, actual);
    }

    @Test
    public void identifyNameTestCookieWithZero(){
        String expected = "cookies";
        String actual = itemParser.identifyName("C0oKies");
        assertEquals(expected, actual);
    }

    @Test
    public void identifyNameTestNull(){
        String expected = null;
        String actual = itemParser.identifyName("bob");
        assertEquals(expected, actual);
    }

    @Test
    public void identifyNameTestApples(){
        String expected = "apples";
        String actual = itemParser.identifyName("aPpLEs");
        assertEquals(expected, actual);
    }

    @Test
    public void identifyNameTestBread(){
        String expected = "bread";
        String actual = itemParser.identifyName("BReAD");
        assertEquals(expected, actual);
    }
}
